<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>飛行模式開啟</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>飛行模式關閉</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>飛航模式</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>飛行模式設定</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>飛行模式</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>我的裝置</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設定</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>藍牙關閉</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>藍牙設定</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 已連接</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>正在連線...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>藍牙關閉</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>已連接%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>未連線</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>藍牙</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>亮度</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>顯示設定</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>顯示設定</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>亮度</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>日</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>一</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>二</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>三</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>四</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>五</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>六</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>添加鍵盤布局</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>時間</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12小時制</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24小時制</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>時間設定</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>打開日曆</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>星期一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>星期二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>星期三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>星期四</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>星期五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>星期六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>星期日</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>週一</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>週二</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>週三</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>週四</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>週五</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>週六</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>週日</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>其他裝置</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>勿擾模式</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>勿擾模式設定</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>勿擾模式開啟</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>勿擾模式關閉</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>勿擾模式</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>護眼模式</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>護眼模式開啟</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>護眼模式關閉</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>顯示設定</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>護眼模式</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>主題</translation>
    </message>
    <message>
        <source>On</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>淺色</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>深色</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>關閉護眼模式</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>開啟護眼模式</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>顯示設定</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>主題：淺色</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>主題：深色</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>主題：自動</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>視覺效果</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>淺色</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>深色</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>主題</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notifications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notification</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>螢幕鍵盤</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>高性能模式</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>平衡模式</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>節能模式</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>電源管理</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>電量%1，剩餘%2分鐘</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>電量%1，剩餘%2小時%3分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>正在充電%1，還需%2分鐘</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>正在充電%1，還需%2小時%3分鐘</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>電量%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>正在充電%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>電量%1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>電量%1，已充滿</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>電量%1，未充電</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>電池</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>正在充電，預計充電時間計算中...</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>剩餘使用時間計算中...</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>剩餘%1分鐘</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>剩餘%1小時%2分鐘</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>未充電</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>已充滿</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>正在充電，還需%1分鐘</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>正在充電，還需%1小時%2分鐘</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>電量%1，剩餘%2小時</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>剩餘%1小時</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>正在充電%1，還需%2小時</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>正在充電，還需%1小時</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>音樂</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>未知</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定螢幕</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>註銷</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>電源設定</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重啟</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>更新並關機</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>更新並重啟</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>今天</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>農曆</translation>
    </message>
    <message>
        <source>y</source>
        <translation>年</translation>
    </message>
    <message>
        <source>m</source>
        <translation>月</translation>
    </message>
    <message>
        <source>d</source>
        <translation>日</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>星期一</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>星期二</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>星期三</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>星期四</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>星期五</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>星期六</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>星期日</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>1月</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>2月</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>3月</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>4月</translation>
    </message>
    <message>
        <source>May</source>
        <translation>5月</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>6月</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>7月</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>8月</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>9月</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>10月</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>11月</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>12月</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>打開日曆</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>週一</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>週二</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>週三</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>週四</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>週五</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>週六</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>週日</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>聲音設定</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>聲音</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>取消靜音</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>靜音</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>聲音設定</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>無聲音輸出裝置</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>目前音量 %1</translation>
    </message>
</context>
</TS>